# Esbonio

Esbonio - to explain.

**This package is in early development**

A Python package that provides a number of Sphinx extensions and a [Language Server]() for enhancing
the editing experience of `*.rst` files in editors.
